@@ -1,40 +1,68 @@
+from typing import List
+
+import random
 import numpy as np
-import networkx as nx
 import scipy.sparse as sp
 import torch
+import torch.utils.data
 
 from cogdl.data import Data
 
+
 class Sampler:
+    r"""
+    Base sampler class.
+    Constructs a sampler with data (`torch_geometric.data.Data`), which indicates Graph to be sampled,
+    and args_params (Dictionary) which represents args parameters needed by the sampler.
+    """
+
     def __init__(self, data, args_params):
-        self.data = data
+        self.data = data.clone()
         self.num_nodes = self.data.x.size()[0]
         self.num_edges = self.data.edge_index.size()[1]
 
     def sample(self):
         pass
 
+
 class SAINTSampler(Sampler):
+    r"""
+    The sampler super-class referenced from GraphSAINT (https://arxiv.org/abs/1907.04931). Any graph sampler is supposed to perform
+    the following meta-steps:
+     1. [optional] Preprocessing: e.g., for edge sampler, we need to calculate the
+            sampling probability for each edge in the training graph. This is to be
+            performed only once per phase (or, once throughout the whole training,
+            since in most cases, training only consists of a single phase).
+            ==> Need to override the `preproc()` in sub-class
+     2. Post-processing: upon getting the sampled subgraphs, we need to prepare the
+            appropriate information (e.g., subgraph adj with renamed indices) to
+            enable the PyTorch trainer.
+    """
+
     def __init__(self, data, args_params):
         super().__init__(data, args_params)
-        self.adj = sp.coo_matrix((np.ones(self.num_edges), (self.data.edge_index[0], self.data.edge_index[1])), 
-                            shape = (self.num_nodes, self.num_nodes)).tocsr()
-        self.node_train = np.arange(1, self.num_nodes + 1) * self.data.train_mask.numpy()
+        edge_index = self.data.edge_index.cpu().numpy()
+        self.adj = sp.coo_matrix(
+            (np.ones(self.num_edges), (edge_index[0], edge_index[1])),
+            shape=(self.num_nodes, self.num_nodes),
+        ).tocsr()
+        self.node_train = np.arange(1, self.num_nodes + 1) * self.data.train_mask.cpu().numpy()
         self.node_train = self.node_train[self.node_train != 0] - 1
 
         self.sample_coverage = args_params["sample_coverage"]
         self.estimate()
 
     def estimate(self):
-        # estimation of loss / aggregation normalization factors
-        # -------------------------------------------------------------
-        # For some special sampler, no need to estimate norm factors, we can calculate
-        # the node / edge probabilities directly.
-        # However, for integrity of the framework, we follow the same procedure
-        # for all samplers:
-        #   1. sample enough number of subgraphs
-        #   2. update the counter for each node / edge in the training graph
-        #   3. estimate norm factor alpha and lambda
+        r"""
+        estimation of loss / aggregation normalization factors.
+        For some special sampler, no need to estimate norm factors, we can calculate
+        the node / edge probabilities directly.
+        However, for integrity of the framework, we follow the same procedure
+        for all samplers:
+            1. sample enough number of subgraphs
+            2. update the counter for each node / edge in the training graph
+            3. estimate norm factor alpha and lambda
+        """
         self.subgraphs_indptr = []
         self.subgraphs_indices = []
         self.subgraphs_data = []
@@ -49,7 +77,12 @@ class SAINTSampler(Sampler):
         tot_sampled_nodes = 0
         while True:
             tot_sampled_nodes += self.gen_subgraph()
-            print("\rGenerating subgraphs %.2lf%%" % (tot_sampled_nodes * 100 / self.data.num_nodes / self.sample_coverage), end = "", flush = True)
+            print(
+                "\rGenerating subgraphs %.2lf%%"
+                % (tot_sampled_nodes * 100 / self.data.num_nodes / self.sample_coverage),
+                end="",
+                flush=True,
+            )
             if tot_sampled_nodes > self.sample_coverage * self.num_nodes:
                 break
         num_subg = len(self.subgraphs_nodes)
@@ -59,10 +92,10 @@ class SAINTSampler(Sampler):
         for v in range(self.data.num_nodes):
             i_s = self.adj.indptr[v]
             i_e = self.adj.indptr[v + 1]
-            val = np.clip(self.norm_loss_train[v] / self.norm_aggr_train[i_s : i_e], 0, 1e4)
+            val = np.clip(self.norm_loss_train[v] / self.norm_aggr_train[i_s:i_e], 0, 1e4)
             val[np.isnan(val)] = 0.1
-            self.norm_aggr_train[i_s : i_e] = val
-        self.norm_loss_train[np.where(self.norm_loss_train==0)[0]] = 0.1
+            self.norm_aggr_train[i_s:i_e] = val
+        self.norm_loss_train[np.where(self.norm_loss_train == 0)[0]] = 0.1
         self.norm_loss_train[self.node_train] = num_subg / self.norm_loss_train[self.node_train] / self.node_train.size
         self.norm_loss_train = torch.from_numpy(self.norm_loss_train.astype(np.float32))
 
@@ -78,14 +111,14 @@ class SAINTSampler(Sampler):
     def sample(self):
         pass
 
-    def extract_subgraph(self, edge_idx, directed = True):
+    def extract_subgraph(self, edge_idx, directed=True):
         edge_idx = np.unique(edge_idx)
-        subg_edge = self.data.edge_index.t()[edge_idx].numpy()
+        subg_edge = self.data.edge_index.t()[edge_idx].cpu().numpy()
         if not directed:
-            subg_edge = np.concatenate((subg_edge, subg_edge[:,[1, 0]]))
-        subg_edge = np.unique(subg_edge, axis = 0)
-        #get nodes whose degree != 0
-        nodes = np.zeros(self.num_nodes, dtype = int)
+            subg_edge = np.concatenate((subg_edge, subg_edge[:, [1, 0]]))
+        subg_edge = np.unique(subg_edge, axis=0)
+        # get nodes whose degree != 0
+        nodes = np.zeros(self.num_nodes, dtype=int)
         for e in subg_edge:
             nodes[e[0]] = 1
             nodes[e[1]] = 1
@@ -95,13 +128,13 @@ class SAINTSampler(Sampler):
                 for i in range(self.adj.indptr[e[0]], self.adj.indptr[e[0] + 1]):
                     if self.adj.indices[i] == e[1]:
                         edge_idx.append(i)
-            edge_idx = np.array(edge_idx, dtype = int)
+            edge_idx = np.array(edge_idx, dtype=int)
         node_idx = np.arange(1, self.num_nodes + 1) * np.array(nodes)
         node_idx = node_idx[node_idx != 0] - 1
 
-        #mapping nodes to new indices
+        # mapping nodes to new indices
         orig2subg = {n: i for i, n in enumerate(node_idx)}
-        indptr = np.zeros(node_idx.size + 1, dtype = int)
+        indptr = np.zeros(node_idx.size + 1, dtype=int)
         for ind, u in enumerate(subg_edge[:, 0]):
             if ind + 1 > indptr[orig2subg[u] + 1]:
                 indptr[orig2subg[u] + 1] = ind + 1
@@ -115,8 +148,8 @@ class SAINTSampler(Sampler):
         assert indptr[-1] == indices.size == subg_edge.size // 2
         return indptr, indices, data, node_idx, edge_idx
 
-    def get_subgraph(self, phase, require_norm = True):
-        """
+    def get_subgraph(self, phase, require_norm=True):
+        r"""
         Generate one minibatch for model. In the 'train' mode, one minibatch corresponds
         to one subgraph of the training graph. In the 'valid' or 'test' mode, one batch
         corresponds to the full graph (i.e., full-batch rather than minibatch evaluation
@@ -131,9 +164,9 @@ class SAINTSampler(Sampler):
             data.norm_aggr      aggregation normalization
             data.norm_loss      normalization normalization
         """
-        if phase in ['val', 'test']:
+        if phase in ["val", "test"]:
             node_subgraph = np.arange(self.data.num_nodes)
-            data = self.data
+            data = self.data.clone()
             if require_norm:
                 data.norm_aggr = torch.ones(self.num_edges)
                 data.norm_loss = self.norm_loss_test
@@ -144,23 +177,27 @@ class SAINTSampler(Sampler):
             node_subgraph = self.subgraphs_nodes.pop()
             edge_subgraph = self.subgraphs_edge_index.pop()
             num_nodes_subgraph = node_subgraph.size
-            adj = sp.csr_matrix((self.subgraphs_data.pop(), self.subgraphs_indices.pop(), self.subgraphs_indptr.pop()), 
-                            shape =(num_nodes_subgraph, num_nodes_subgraph))
+            adj = sp.csr_matrix(
+                (self.subgraphs_data.pop(), self.subgraphs_indices.pop(), self.subgraphs_indptr.pop()),
+                shape=(num_nodes_subgraph, num_nodes_subgraph),
+            )
 
             if require_norm:
                 adj.data[:] = self.norm_aggr_train[edge_subgraph][:]
-                #normalization
+                # normalization
                 D = adj.sum(1).flatten()
-                norm_diag = sp.dia_matrix((1 / D, 0), shape = adj.shape)
+                norm_diag = sp.dia_matrix((1 / D, 0), shape=adj.shape)
                 adj = norm_diag.dot(adj)
                 adj.sort_indices()
 
             adj = adj.tocoo()
-            data = Data(self.data.x[node_subgraph], 
-                        torch.LongTensor(np.vstack((adj.row, adj.col))),
-                        None if self.data.edge_attr is None else self.data.edge_attr[edge_subgraph], 
-                        self.data.y[node_subgraph], 
-                        None if self.data.pos is None else self.data.pos[node_subgraph])
+            data = Data(
+                self.data.x[node_subgraph],
+                torch.LongTensor(np.vstack((adj.row, adj.col))),
+                None if self.data.edge_attr is None else self.data.edge_attr[edge_subgraph],
+                self.data.y[node_subgraph],
+                None if self.data.pos is None else self.data.pos[node_subgraph],
+            )
 
             if require_norm:
                 data.norm_aggr = torch.FloatTensor(adj.data)
@@ -171,11 +208,19 @@ class SAINTSampler(Sampler):
 
         return data
 
+
 class NodeSampler(SAINTSampler):
+    r"""
+    randomly select nodes, then adding edges connecting these nodes
+    Args:
+        sample_coverage (integer):  number of sampled nodes during estimation / number of nodes in graph
+        size_subgraph (integer): number of nodes in subgraph
+    """
+
     def __init__(self, data, args_params):
         self.node_num_subgraph = args_params["size_subgraph"]
         super().__init__(data, args_params)
-        
+
     def sample(self):
         node_idx = np.random.choice(np.arange(self.num_nodes), self.node_num_subgraph)
         node_idx = np.unique(node_idx)
@@ -186,7 +231,7 @@ class NodeSampler(SAINTSampler):
         subg_edge_index = []
         for nid in node_idx:
             idx_s, idx_e = self.adj.indptr[nid], self.adj.indptr[nid + 1]
-            neighs = self.adj.indices[idx_s : idx_e]
+            neighs = self.adj.indices[idx_s:idx_e]
             for i_n, n in enumerate(neighs):
                 if n in orig2subg:
                     indices.append(orig2subg[n])
@@ -198,8 +243,16 @@ class NodeSampler(SAINTSampler):
         data = np.ones(indices.size)
         assert indptr[-1] == indices.size == subg_edge_index.size
         return indptr, indices, data, node_idx, subg_edge_index
-        
+
+
 class EdgeSampler(SAINTSampler):
+    r"""
+    randomly select edges, then adding nodes connected by these edges
+    Args:
+        sample_coverage (integer):  number of sampled nodes during estimation / number of nodes in graph
+        size_subgraph (integer): number of edges in subgraph
+    """
+
     def __init__(self, data, args_params):
         self.edge_num_subgraph = args_params["size_subgraph"]
         super().__init__(data, args_params)
@@ -208,7 +261,16 @@ class EdgeSampler(SAINTSampler):
         edge_idx = np.random.choice(np.arange(self.num_edges), self.edge_num_subgraph)
         return self.extract_subgraph(edge_idx)
 
+
 class RWSampler(SAINTSampler):
+    r"""
+    randomly select a node, perform a random walk starting from the node and add the walk path to the subgraph
+    Args:
+        sample_coverage (integer):  number of sampled nodes during estimation / number of nodes in graph
+        num_walks (integer): number of walks
+        walk_length (integer): length of the random walk
+    """
+
     def __init__(self, data, args_params):
         self.num_walks = args_params["num_walks"]
         self.walk_length = args_params["walk_length"]
@@ -224,10 +286,19 @@ class RWSampler(SAINTSampler):
                 e = np.random.randint(idx_s, idx_e)
                 edge_idx.append(e)
                 u = self.adj.indices[e]
-        
+
         return self.extract_subgraph(np.array(edge_idx))
 
+
 class MRWSampler(SAINTSampler):
+    r"""
+    multidimentional random walk, similar to https://arxiv.org/abs/1002.1751
+    Args:
+        sample_coverage (integer):  number of sampled nodes during estimation / number of nodes in graph
+        size_frontier (integer): number of frontiers
+        size_subgraph (integer): number of edges in subgraph
+    """
+
     def __init__(self, data, args_params):
         self.size_frontier = args_params["size_frontier"]
         self.edge_num_subgraph = args_params["size_subgraph"]
@@ -256,6 +327,7 @@ class MRWSampler(SAINTSampler):
 
         return self.extract_subgraph(np.array(edge_idx))
 
+
 class LayerSampler(Sampler):
     def __init__(self, data, model, params_args):
         super().__init__(data, params_args)
@@ -269,10 +341,56 @@ class LayerSampler(Sampler):
         total = train_nodes.shape[0]
         for i in range(0, total, batch_size):
             if i + batch_size <= total:
-                cur_nodes = train_nodes[i: i+batch_size]
+                cur_nodes = train_nodes[i : i + batch_size]
                 cur_labels = train_labels[cur_nodes]
                 yield cur_nodes, cur_labels
 
+
+class NeighborSampler(torch.utils.data.DataLoader):
+    def __init__(self, data: Data, sizes: List[int], mask=None, **kwargs):
+        self.data = data
+        self.sizes = sizes
+        node_idx = np.arange(0, data.x.shape[0])
+        if mask is not None:
+            node_idx = node_idx[mask]
+        node_idx = node_idx.tolist()
+        super(NeighborSampler, self).__init__(node_idx, collate_fn=self.sample, **kwargs)
+
+    def sample(self, batch):
+        """
+            Sample a subgraph with neighborhood sampling
+        Args:
+            batch: torch.Tensor / np.array
+                Target nodes
+        Returns:
+            if `size` is `[-1,]`,
+                (
+                    source_nodes_id: Tensor,
+                    sampled_edges: Tensor,
+                    (number_of_source_nodes, number_of_target_nodes): Tuple[int]
+                )
+            otherwise,
+                (
+                    target_nodes_id: Tensor
+                    all_sampled_nodes_id: Tensor,
+                    sampled_adjs: List[Tuple(Tensor, Tensor, Tuple[int]]
+                )
+        """
+        node_id = batch
+        adj_list = []
+        for size in self.sizes:
+            src_id, _edge_index = self.data.sample_adj(node_id, size, replace=False)
+            size = (len(src_id), len(node_id))
+            adj_list.append((src_id, _edge_index, size))  # src_id, edge_index, (src_size, target_size)
+            node_id = src_id
+        if self.sizes == [-1]:
+            src_id, edge_index, _ = adj_list[0]
+            size = (len(src_id), len(batch))
+            return src_id, edge_index, size
+        else:
+            return batch, node_id, adj_list[::-1]
+
+
 """class FastGCNSampler(LayerSampler):
     def __init__(self, data, params_args):
         super().__init__(data, params_args)
@@ -377,11 +495,11 @@ class ASGCNSampler(LayerSampler):
 
         samples = torch.multinomial(p1, sample_size, False)
         u_sampled = u[samples]
-            
+
         support_sampled = torch.index_select(support, 1, samples)
 
         return u_sampled, support_sampled
-    
+
     def sample(self, x, v, num_layers):
         all_support = [[] for _ in range(num_layers)]
         sampled = v
