@@ -7,6 +7,4 @@ class BaseTrainer(ABC):
     @abstractmethod
     def build_trainer_from_args(cls, args):
         """Build a new trainer instance."""
-        raise NotImplementedError(
-            "Trainers must implement the build_trainer_from_args method"
-        )
+        raise NotImplementedError("Trainers must implement the build_trainer_from_args method")
