@@ -1,8 +1,8 @@
 from abc import ABC, abstractmethod
-from typing import Any
 
 from cogdl.data import Dataset
 from cogdl.models.supervised_model import (
+    SupervisedModel,
     SupervisedHeterogeneousNodeClassificationModel,
     SupervisedHomogeneousNodeClassificationModel,
 )
@@ -11,33 +11,21 @@ from cogdl.trainers.base_trainer import BaseTrainer
 
 class SupervisedTrainer(BaseTrainer, ABC):
     @abstractmethod
-    def fit(self) -> None:
-        raise NotImplemented
-
-    @abstractmethod
-    def predict(self) -> Any:
-        raise NotImplemented
+    def fit(self, model: SupervisedModel, dataset) -> None:
+        raise NotImplementedError
 
 
 class SupervisedHeterogeneousNodeClassificationTrainer(BaseTrainer, ABC):
     @abstractmethod
-    def fit(
-        self, model: SupervisedHeterogeneousNodeClassificationModel, dataset: Dataset
-    ) -> None:
-        raise NotImplemented
-
-    # @abstractmethod
-    # def evaluate(self, data: Any, nodes: Any, targets: Any) -> Any:
-    #     raise NotImplemented
+    def fit(self, model: SupervisedHeterogeneousNodeClassificationModel, dataset: Dataset) -> None:
+        raise NotImplementedError
 
 
 class SupervisedHomogeneousNodeClassificationTrainer(BaseTrainer, ABC):
     @abstractmethod
-    def fit(
-        self, model: SupervisedHomogeneousNodeClassificationModel, dataset: Dataset
-    ) -> None:
-        raise NotImplemented
+    def fit(self, model: SupervisedHomogeneousNodeClassificationModel, dataset: Dataset) -> None:
+        raise NotImplementedError
 
     # @abstractmethod
     # def predictAll(self) -> Any:
-    #     raise NotImplemented
+    #     raise NotImplementedError
